import React, { PureComponent, MouseEvent, TouchEvent } from 'react';
import { GlarePosition } from './features/Glare';
declare type DOMSupportedEvent = MouseEvent<HTMLDivElement> | TouchEvent | DeviceOrientationEvent;
declare type SupportedEvent = DOMSupportedEvent | CustomEvent<CustomEventType>;
declare type CustomEventType = 'autoreset' | 'propchange';
export declare type Axis = 'x' | 'y';
export declare type TiltProps = {
    /**
     * Boolean to enable/disable tilt effect.
     */
    tiltEnable?: boolean;
    /**
     * Reverse the tilt direction.
     */
    tiltReverse?: boolean;
    /**
     * Max tilt rotation (degrees) on x axis. Range: 0 - 90
     */
    tiltMaxAngleX?: number;
    /**
     * Max tilt rotation (degrees) on y axis. Range: 0 - 90
     */
    tiltMaxAngleY?: number;
    /**
     * Which axis should be enabled. If null both are enabled.
     */
    tiltAxis?: Axis | null;
    /**
     * Manual tilt rotation (degrees) on x axis.
     */
    tiltAngleXManual?: number | null;
    /**
     * Manual tilt rotation (degrees) on y axis.
     */
    tiltAngleYManual?: number | null;
};
export declare type GlareProps = {
    /**
     * Boolean to enable/disable glare effect.
     */
    glareEnable?: boolean;
    /**
     * The maximum glare opacity (0.5 = 50%, 1 = 100%, etc.). Range: 0 - 1
     */
    glareMaxOpacity?: number;
    /**
     * Set color of glare effect.
     */
    glareColor?: string;
    /**
     * Set position of glare effect.
     */
    glarePosition?: GlarePosition;
    /**
     * Reverse the glare direction.
     */
    glareReverse?: boolean;
};
export interface Props extends TiltProps, GlareProps, React.HTMLAttributes<HTMLDivElement> {
    /**
     * Scale of the component (1.5 = 150%, 2 = 200%, etc.).
     */
    scale?: number;
    /**
     * The perspective property defines how far the object (wrapped/child component) is away from the user. The lower the more extreme the tilt gets.
     */
    perspective?: number;
    /**
     * Boolean to enable/disable vertical flip of component.
     */
    flipVertically?: boolean;
    /**
     * Boolean to enable/disable horizontal flip of component.
     */
    flipHorizontally?: boolean;
    /**
     * If the effects has to be reset on "onLeave" event.
     */
    reset?: boolean;
    /**
     * Easing of the transition when manipulating the component.
     */
    transitionEasing?: string;
    /**
     * Speed of the transition when manipulating the component.
     */
    transitionSpeed?: number;
    /**
     * Boolean to enable/disable device orientation detection.
     */
    gyroscope?: boolean;
    /**
     * Gets triggered when user moves on the component.
     */
    onMove?: (tiltAngleX: number, tiltAngleY: number, tiltAngleXPercentage: number, tiltAngleYPercentage: number, glareAngle: number, glareOpacity: number, eventType: string | null) => void;
    /**
     * Gets triggered when user enters the component.
     */
    onEnter?: (eventType: string) => void;
    /**
     * Gets triggered when user leaves the component.
     */
    onLeave?: (eventType: string) => void;
}
declare class ReactParallaxTilt extends PureComponent<Props> {
    static defaultProps: Props;
    private wrapperEl;
    private tilt;
    private glare;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(): void;
    private addEventListeners;
    private removeEventListeners;
    private initGlare;
    mainLoop: (event: SupportedEvent) => void;
    onWindowResize: () => void;
    private setWrapperElSize;
    private onEnter;
    private onMove;
    private onLeave;
    private processInput;
    private processInputDeviceOrientation;
    private update;
    private updateClientInput;
    private updateFlip;
    renderFrame: () => void;
    private resetWrapperElTransform;
    private renderPerspective;
    private renderScale;
    private setTransition;
    render(): JSX.Element;
}
export default ReactParallaxTilt;
